@@ -296,6 +296,7 @@ void SheetBrowser::showNoteEditWidget(deepin_reader::Annotation *annotation, con
             setIconAnnotSelect(false);
         });
     }
+    m_noteEditWidget->updateHeight();
 
     m_noteEditWidget->getTextEditWidget()->setEditText(annotation->contents());
     m_noteEditWidget->getTextEditWidget()->setAnnotation(annotation);
@@ -938,9 +939,6 @@ void SheetBrowser::resizeEvent(QResizeEvent *event)
         m_sheet->setOperationChanged();
     }
 
-    if (!m_findWidget.isNull())
-        m_findWidget->showPosition(this->width());
-
     if (magnifierOpened()) {
         QTimer::singleShot(1, this, SLOT(openMagnifier()));
     }
@@ -1633,11 +1631,13 @@ void SheetBrowser::handlePrepareSearch()
         return;
 
     if (m_findWidget == nullptr) {
-        m_findWidget = new FindWidget(this);
+        m_findWidget = new FindWidget(this->window());
+        int windowY = this->mapTo(this->window(), QPoint(0, 0)).y();
+        m_findWidget->setYOff(windowY);
         m_findWidget->setDocSheet(m_sheet);
     }
 
-    m_findWidget->showPosition(this->width());
+    m_findWidget->updatePosition();
     m_findWidget->setSearchEditFocus();
 }
 
@@ -1871,8 +1871,8 @@ bool SheetBrowser::jump2Link(QPointF point)
 
         SecurityDialog *sdialog = new SecurityDialog(link.urlOrFileName, this);
         if (DDialog::Accepted == sdialog->exec()) {
-            const QUrl &url = QUrl(urlstr, QUrl::TolerantMode);
-            QDesktopServices::openUrl(url);
+//            const QUrl &url = QUrl(urlstr, QUrl::TolerantMode);
+            QDesktopServices::openUrl(QUrl::fromLocalFile(urlstr));
         }
         return true;
     }
