@@ -184,9 +184,9 @@ TEST_F(TestSlideWidget, testonNextBtnClicked)
     m_tester->m_curPageIndex = 2;
 
     m_tester->onNextBtnClicked();
-//    EXPECT_EQ(m_tester->m_preIndex, 2);
-//    EXPECT_EQ(m_tester->m_curPageIndex, 2);
-//    EXPECT_TRUE(g_funcname == "playImage_stub");
+    EXPECT_EQ(m_tester->m_preIndex, 2);
+    EXPECT_EQ(m_tester->m_curPageIndex, 0);
+    EXPECT_TRUE(g_funcname == "playImage_stub");
 }
 
 TEST_F(TestSlideWidget, testononExitBtnClicked)
