@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="en">
 <context>
     <name>Application</name>
     <message>
@@ -241,7 +243,7 @@
 <context>
     <name>Central</name>
     <message>
-        <location filename="../reader/uiframe/Central.cpp" line="145"/>
+        <location filename="../reader/uiframe/Central.cpp" line="141"/>
         <source>Documents</source>
         <translation>Documents</translation>
     </message>
@@ -318,20 +320,20 @@
 <context>
     <name>DocSheet</name>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
         <source>The bookmark has been removed</source>
         <translation>The bookmark has been removed</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
         <source>Please select the text</source>
         <translation>Please select the text</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
         <source>The annotation has been removed</source>
         <translation>The annotation has been removed</translation>
     </message>
@@ -871,19 +873,6 @@
         <translation>Page %1</translation>
     </message>
 </context>
-<context>
-    <name>SlidePlayWidget</name>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
-        <source>It is the first page</source>
-        <translation>It is the first page</translation>
-    </message>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
-        <source>It is the last page</source>
-        <translation>It is the last page</translation>
-    </message>
-</context>
 <context>
     <name>TitleMenu</name>
     <message>
@@ -930,7 +919,7 @@
     <message>
         <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
         <source>Print</source>
-        <translation>Print</translation>
+        <translation type="unfinished">Print</translation>
     </message>
 </context>
 <context>
@@ -973,4 +962,4 @@
         <translation>Generate thumbnail.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
