@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
     <name>Application</name>
     <message>
@@ -242,7 +244,7 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
 <context>
     <name>Central</name>
     <message>
-        <location filename="../reader/uiframe/Central.cpp" line="145"/>
+        <location filename="../reader/uiframe/Central.cpp" line="141"/>
         <source>Documents</source>
         <translation>Documenti</translation>
     </message>
@@ -319,20 +321,20 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
 <context>
     <name>DocSheet</name>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
         <source>The bookmark has been removed</source>
         <translation>Il segnalibro è stato rimosso</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
         <source>Please select the text</source>
         <translation>Seleziona il testo</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
         <source>The annotation has been removed</source>
         <translation>L&apos;annotazione è stata rimossa</translation>
     </message>
@@ -872,19 +874,6 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
         <translation>Pagina %1</translation>
     </message>
 </context>
-<context>
-    <name>SlidePlayWidget</name>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
-        <source>It is the first page</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
-        <source>It is the last page</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>TitleMenu</name>
     <message>
@@ -931,7 +920,7 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
     <message>
         <location filename="../reader/uiframe/TitleMenu.cpp" line="54"/>
         <source>Print</source>
-        <translation>Stampa</translation>
+        <translation type="unfinished">Stampa</translation>
     </message>
 </context>
 <context>
@@ -974,4 +963,4 @@ Localizzazione italiana a cura di Massimo A. Carofano.</translation>
         <translation>Genera miniatura.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
