@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="pl">
 <context>
     <name>Application</name>
     <message>
@@ -241,7 +243,7 @@
 <context>
     <name>Central</name>
     <message>
-        <location filename="../reader/uiframe/Central.cpp" line="145"/>
+        <location filename="../reader/uiframe/Central.cpp" line="141"/>
         <source>Documents</source>
         <translation>Dokumenty</translation>
     </message>
@@ -318,20 +320,20 @@
 <context>
     <name>DocSheet</name>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
         <source>The bookmark has been removed</source>
         <translation>Zakładka została usunięta</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
         <source>Please select the text</source>
         <translation>Zaznacz tekst</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
         <source>The annotation has been removed</source>
         <translation>Adnotacja została usunięta</translation>
     </message>
@@ -573,7 +575,7 @@
     <message>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="142"/>
         <source>Edit</source>
-        <translation>Edytuj</translation>
+        <translation>Edycja</translation>
     </message>
     <message>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
@@ -597,7 +599,7 @@
         <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
         <source>Page up</source>
-        <translation>Strona w górę</translation>
+        <translation>Przewiń stronę w górę</translation>
     </message>
     <message>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
@@ -605,7 +607,7 @@
         <location filename="../reader/widgets/ShortCutShow.cpp" line="234"/>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="245"/>
         <source>Page down</source>
-        <translation>Strona w dół</translation>
+        <translation>Przewiń stronę w dół</translation>
     </message>
     <message>
         <location filename="../reader/widgets/ShortCutShow.cpp" line="193"/>
@@ -871,19 +873,6 @@
         <translation>Strona %1</translation>
     </message>
 </context>
-<context>
-    <name>SlidePlayWidget</name>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
-        <source>It is the first page</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
-        <source>It is the last page</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>TitleMenu</name>
     <message>
@@ -973,4 +962,4 @@
         <translation>Wygeneruj miniaturę.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
