@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="zh_CN">
 <context>
     <name>Application</name>
     <message>
@@ -241,7 +243,7 @@
 <context>
     <name>Central</name>
     <message>
-        <location filename="../reader/uiframe/Central.cpp" line="145"/>
+        <location filename="../reader/uiframe/Central.cpp" line="141"/>
         <source>Documents</source>
         <translation>文档文件</translation>
     </message>
@@ -318,20 +320,20 @@
 <context>
     <name>DocSheet</name>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="327"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="355"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="326"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="354"/>
         <source>The bookmark has been removed</source>
         <translation>已删除书签</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="528"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="543"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="527"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="542"/>
         <source>Please select the text</source>
         <translation>请选择文本</translation>
     </message>
     <message>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="593"/>
-        <location filename="../reader/uiframe/DocSheet.cpp" line="602"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="592"/>
+        <location filename="../reader/uiframe/DocSheet.cpp" line="601"/>
         <source>The annotation has been removed</source>
         <translation>已删除注释</translation>
     </message>
@@ -871,19 +873,6 @@
         <translation>第%1页</translation>
     </message>
 </context>
-<context>
-    <name>SlidePlayWidget</name>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="127"/>
-        <source>It is the first page</source>
-        <translation>已是第一页</translation>
-    </message>
-    <message>
-        <location filename="../reader/widgets/SlidePlayWidget.cpp" line="132"/>
-        <source>It is the last page</source>
-        <translation>已是最后一页</translation>
-    </message>
-</context>
 <context>
     <name>TitleMenu</name>
     <message>
@@ -973,4 +962,4 @@
         <translation>Generate thumbnail.</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
